@@ -254,12 +254,14 @@ public:
  * from the ALSA sequencer subsystem.
  *
  * @param parent The optional parent object
- * @return a MidiClient instance
  */
 MidiClient::MidiClient( QObject* parent ) :
     QObject(parent),
     d(new MidiClientPrivate)
-{ }
+{ 
+    qRegisterMetaType<drumstick::ALSA::SequencerEvent>();
+    qRegisterMetaType<drumstick::ALSA::SequencerEvent*>();
+}
 
 /**
  * Destructor.
