@@ -1,10 +1,10 @@
 /*
     MIDI Sequencer C++ library 
-    Copyright (C) 2006-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
  
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
  
     This library is distributed in the hope that it will be useful,
@@ -16,10 +16,11 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
+#include "errorcheck.h"
 #include <cmath>
-#include <drumstick/alsaqueue.h>
 #include <drumstick/alsaclient.h>
 #include <drumstick/alsaevent.h>
+#include <drumstick/alsaqueue.h>
 #include <drumstick/alsatimer.h>
 
 /**
@@ -28,6 +29,13 @@
  */
 
 namespace drumstick {
+namespace ALSA {
+
+/**
+ * This is the value for the base skew used in ALSA. It is not possible
+ * to assign an arbitrary value (ALSA version <= 1.0.20).
+ */
+const unsigned int SKEW_BASE = 0x10000;
 
 /**
  * @addtogroup ALSAQueue
@@ -49,7 +57,7 @@ namespace drumstick {
  *
  * MidiQueue represents the queue object.
  *
- * @see http://www.alsa-project.org/alsa-doc/alsa-lib/group___seq_queue.html
+ * @see https://www.alsa-project.org/alsa-doc/alsa-lib/group___seq_queue.html
  * @}
  */
 
@@ -105,6 +113,8 @@ QueueInfo* QueueInfo::clone()
  */
 QueueInfo& QueueInfo::operator=(const QueueInfo& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_queue_info_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -252,6 +262,8 @@ QueueStatus* QueueStatus::clone()
  */
 QueueStatus& QueueStatus::operator=(const QueueStatus& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_queue_status_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -381,6 +393,8 @@ QueueTempo* QueueTempo::clone()
  */
 QueueTempo& QueueTempo::operator=(const QueueTempo& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_queue_tempo_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -578,6 +592,8 @@ QueueTimer* QueueTimer::clone()
  */
 QueueTimer& QueueTimer::operator=(const QueueTimer& other)
 {
+    if (this == &other)
+        return *this;
     snd_seq_queue_timer_copy(m_Info, other.m_Info);
     return *this;
 }
@@ -688,7 +704,7 @@ MidiQueue::MidiQueue(MidiClient* seq, QObject* parent)
     : QObject(parent)
 {
     m_MidiClient = seq;
-    m_Id = CHECK_ERROR(snd_seq_alloc_queue(m_MidiClient->getHandle()));
+    m_Id = DRUMSTICK_ALSA_CHECK_ERROR(snd_seq_alloc_queue(m_MidiClient->getHandle()));
     m_allocated = !(m_Id < 0);
 }
 
@@ -703,7 +719,7 @@ MidiQueue::MidiQueue(MidiClient* seq, const QueueInfo& info, QObject* parent)
 {
     m_MidiClient = seq;
     m_Info = info;
-    m_Id = CHECK_ERROR(snd_seq_create_queue(m_MidiClient->getHandle(), m_Info.m_Info));
+    m_Id = DRUMSTICK_ALSA_CHECK_ERROR(snd_seq_create_queue(m_MidiClient->getHandle(), m_Info.m_Info));
     m_allocated = !(m_Id < 0);
 }
 
@@ -717,7 +733,7 @@ MidiQueue::MidiQueue(MidiClient* seq, const QString name, QObject* parent)
     : QObject(parent)
 {
     m_MidiClient = seq;
-    m_Id = CHECK_ERROR(snd_seq_alloc_named_queue(m_MidiClient->getHandle(), name.toLocal8Bit().data()));
+    m_Id = DRUMSTICK_ALSA_CHECK_ERROR(snd_seq_alloc_named_queue(m_MidiClient->getHandle(), name.toLocal8Bit().data()));
     m_allocated = !(m_Id < 0);
 }
 
@@ -742,9 +758,9 @@ MidiQueue::MidiQueue(MidiClient* seq, const int queue_id, QObject* parent)
  */
 MidiQueue::~MidiQueue()
 {
-    if ( m_allocated && (m_MidiClient->getHandle() != NULL) )
+    if ( m_allocated && (m_MidiClient->getHandle() != nullptr) )
     {
-        CHECK_ERROR(snd_seq_free_queue(m_MidiClient->getHandle(), m_Id));
+        DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_free_queue(m_MidiClient->getHandle(), m_Id));
     }
 }
 
@@ -754,7 +770,7 @@ MidiQueue::~MidiQueue()
  */
 QueueInfo& MidiQueue::getInfo()
 {
-    CHECK_WARNING(snd_seq_get_queue_info(m_MidiClient->getHandle(), m_Id, m_Info.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_queue_info(m_MidiClient->getHandle(), m_Id, m_Info.m_Info));
     return m_Info;
 }
 
@@ -764,7 +780,7 @@ QueueInfo& MidiQueue::getInfo()
  */
 QueueStatus& MidiQueue::getStatus()
 {
-    CHECK_WARNING(snd_seq_get_queue_status(m_MidiClient->getHandle(), m_Id, m_Status.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_queue_status(m_MidiClient->getHandle(), m_Id, m_Status.m_Info));
     return m_Status;
 }
 
@@ -774,7 +790,7 @@ QueueStatus& MidiQueue::getStatus()
  */
 QueueTempo& MidiQueue::getTempo()
 {
-    CHECK_WARNING(snd_seq_get_queue_tempo(m_MidiClient->getHandle(), m_Id, m_Tempo.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_queue_tempo(m_MidiClient->getHandle(), m_Id, m_Tempo.m_Info));
     return m_Tempo;
 }
 
@@ -784,7 +800,7 @@ QueueTempo& MidiQueue::getTempo()
  */
 QueueTimer& MidiQueue::getTimer()
 {
-    CHECK_WARNING(snd_seq_get_queue_timer(m_MidiClient->getHandle(), m_Id, m_Timer.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_queue_timer(m_MidiClient->getHandle(), m_Id, m_Timer.m_Info));
     return m_Timer;
 }
 
@@ -795,7 +811,7 @@ QueueTimer& MidiQueue::getTimer()
 void MidiQueue::setInfo(const QueueInfo& value)
 {
     m_Info = value;
-    CHECK_WARNING(snd_seq_set_queue_info(m_MidiClient->getHandle(), m_Id, m_Info.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_set_queue_info(m_MidiClient->getHandle(), m_Id, m_Info.m_Info));
 }
 
 /**
@@ -805,7 +821,7 @@ void MidiQueue::setInfo(const QueueInfo& value)
 void MidiQueue::setTempo(const QueueTempo& value)
 {
     m_Tempo = value;
-    CHECK_WARNING(snd_seq_set_queue_tempo(m_MidiClient->getHandle(), m_Id, m_Tempo.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_set_queue_tempo(m_MidiClient->getHandle(), m_Id, m_Tempo.m_Info));
 }
 
 /**
@@ -815,7 +831,7 @@ void MidiQueue::setTempo(const QueueTempo& value)
 void MidiQueue::setTimer(const QueueTimer& value)
 {
     m_Timer = value;
-    CHECK_WARNING(snd_seq_set_queue_timer(m_MidiClient->getHandle(), m_Id, m_Timer.m_Info));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_set_queue_timer(m_MidiClient->getHandle(), m_Id, m_Timer.m_Info));
 }
 
 /**
@@ -825,7 +841,7 @@ void MidiQueue::setTimer(const QueueTimer& value)
  */
 int MidiQueue::getUsage()
 {
-    return CHECK_WARNING(snd_seq_get_queue_usage(m_MidiClient->getHandle(), m_Id));
+    return DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_get_queue_usage(m_MidiClient->getHandle(), m_Id));
 }
 
 /**
@@ -835,7 +851,7 @@ int MidiQueue::getUsage()
  */
 void MidiQueue::setUsage(int used)
 {
-    CHECK_WARNING(snd_seq_set_queue_usage(m_MidiClient->getHandle(), m_Id, used));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_set_queue_usage(m_MidiClient->getHandle(), m_Id, used));
 }
 
 /**
@@ -845,8 +861,8 @@ void MidiQueue::setUsage(int used)
  */
 void MidiQueue::start()
 {
-    CHECK_WARNING(snd_seq_start_queue(m_MidiClient->getHandle(), m_Id, NULL));
-    CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_start_queue(m_MidiClient->getHandle(), m_Id, nullptr));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
 }
 
 /**
@@ -856,9 +872,9 @@ void MidiQueue::start()
  */
 void MidiQueue::stop()
 {
-    if (m_MidiClient != NULL && m_MidiClient->getHandle() != NULL) {
-        CHECK_WARNING(snd_seq_stop_queue(m_MidiClient->getHandle(), m_Id, NULL));
-        CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
+    if (m_MidiClient != nullptr && m_MidiClient->getHandle() != nullptr) {
+        DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_stop_queue(m_MidiClient->getHandle(), m_Id, nullptr));
+        DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
     }
 }
 
@@ -869,8 +885,8 @@ void MidiQueue::stop()
  */
 void MidiQueue::continueRunning()
 {
-    CHECK_WARNING(snd_seq_continue_queue(m_MidiClient->getHandle(), m_Id, NULL));
-    CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_continue_queue(m_MidiClient->getHandle(), m_Id, nullptr));
+    DRUMSTICK_ALSA_CHECK_WARNING(snd_seq_drain_output(m_MidiClient->getHandle()));
 }
 
 /**
@@ -878,7 +894,7 @@ void MidiQueue::continueRunning()
  */
 void MidiQueue::clear()
 {
-    if (m_MidiClient != NULL && m_MidiClient->getHandle() != NULL)
+    if (m_MidiClient != nullptr && m_MidiClient->getHandle() != nullptr)
         snd_seq_drop_output(m_MidiClient->getHandle());
 }
 
@@ -906,4 +922,6 @@ void MidiQueue::setRealTimePosition(snd_seq_real_time_t* pos)
     m_MidiClient->outputDirect(&event);
 }
 
-} /* namespace drumstick */
+} // namespace ALSA
+} // namespace drumstick
+
