@@ -1,10 +1,10 @@
 /*
     WRK File component
-    Copyright (C) 2010-2019, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2010-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This library is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This library is distributed in the hope that it will be useful,
@@ -16,21 +16,24 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <cmath>
 #include <QDataStream>
 #include <QFile>
 #include <QIODevice>
-#include <QTextStream>
-#include <QTextCodec>
 #include <QStringList>
+#include <QTextCodec>
+#include <QTextStream>
+#include <cmath>
 #include <drumstick/qwrk.h>
 
+DISABLE_WARNING_PUSH
+DISABLE_WARNING_DEPRECATED_DECLARATIONS
+
 /**
  * @file qwrk.cpp
  * Implementation of a class managing Cakewalk WRK Files input
  */
 
-namespace drumstick {
+namespace drumstick { namespace File {
 
 /**
  * @addtogroup WRK
@@ -77,8 +80,8 @@ public:
     m_PunchOutTime(0),
     m_EndAllTime(0),
     m_division(120),
-    m_codec(0),
-    m_IOStream(0)
+    m_codec(nullptr),
+    m_IOStream(nullptr)
     { }
 
     quint32 m_Now;          ///< Now marker time
@@ -116,10 +119,14 @@ public:
     QDataStream *m_IOStream;
     QByteArray m_lastChunkData;
     QList<RecTempo> m_tempos;
+
+    qint64 m_lastChunkPos;
+    qint64 internalFilePos();
 };
 
 /**
  * Constructor
+ * @param parent Object owner
  */
 QWrk::QWrk(QObject * parent) :
     QObject(parent),
@@ -130,13 +137,13 @@ QWrk::QWrk(QObject * parent) :
  * Destructor
  */
 QWrk::~QWrk()
-{
-    delete d;
-}
+{ }
 
 /**
- * Gets the text codec used for text meta-events I/O
+ * Gets the text codec used for text meta-events I/O.
+ *
  * @return QTextCodec pointer
+ * @deprecated because the class QTextCodec was removed from QtCore since Qt6.
  */
 QTextCodec* QWrk::getTextCodec()
 {
@@ -148,6 +155,7 @@ QTextCodec* QWrk::getTextCodec()
  * The engine doesn't take ownership of the codec instance.
  *
  * @param codec QTextCodec pointer
+ * @deprecated because the class QTextCodec was removed from QtCore since Qt6.
  */
 void QWrk::setTextCodec(QTextCodec *codec)
 {
@@ -169,7 +177,12 @@ QByteArray QWrk::getLastChunkRawData() const
  */
 void QWrk::readRawData(int size)
 {
-    d->m_lastChunkData = d->m_IOStream->device()->read(size);
+    if (size > 0) {
+        d->m_lastChunkData = d->m_IOStream->device()->read(size);
+    } else {
+        d->m_lastChunkData.clear();
+        //qDebug() << Q_FUNC_INFO << "Size error:" << size;
+    }
 }
 
 /**
@@ -545,35 +558,64 @@ quint32 QWrk::read32bit()
 }
 
 /**
- * Reads a string
+ * Reads a string assuming local encoding if getTextCodec() is null
  * @return a string
  */
 QString QWrk::readString(int len)
 {
     QString s;
     if ( len > 0 ) {
-        quint8 c = 0xff;
-        QByteArray data;
-        for ( int i = 0; i < len && c != 0 && !atEnd(); ++i ) {
-            c = readByte();
-            if ( c != 0)
-                data += c;
-        }
-        if (d->m_codec == NULL)
-            s = QString(data);
-        else
+        QByteArray data = readByteArray(len);
+        if (d->m_codec == nullptr) {
+            s = QString::fromLatin1(data);
+        } else {
             s = d->m_codec->toUnicode(data);
+        }
     }
     return s;
 }
 
+/**
+ * Reads a string as a QByteArray (without decoding)
+ * @return a string
+ */
+QByteArray QWrk::readByteArray(int len)
+{
+    QByteArray data;
+    if ( len > 0 ) {
+        quint8 c = 0xff;
+        for ( int i = 0; i < len && c != 0 && !atEnd(); ++i ) {
+            c = readByte();
+            if ( c != 0)
+                data += c;
+        }
+    }
+    return data;
+}
+
 /**
  * Reads a variable length string (C-style)
+ * (assuming local encoding if getTextCodec() is null)
  * @return a string
  */
 QString QWrk::readVarString()
 {
     QString s;
+    QByteArray data = readVarByteArray();
+    if (d->m_codec == nullptr) {
+        s = QString::fromLatin1(data);
+    } else {
+        s = d->m_codec->toUnicode(data);
+    }
+    return s;
+}
+
+/**
+ * Reads a variable length string (C-style) as a QByteArray (without decoding)
+ * @return a string
+ */
+QByteArray QWrk::readVarByteArray()
+{
     QByteArray data;
     quint8 b;
     do {
@@ -581,11 +623,26 @@ QString QWrk::readVarString()
         if (b != 0)
             data += b;
     } while (b != 0 && !atEnd());
-    if (d->m_codec == NULL)
-        s = QString(data);
-    else
-        s = d->m_codec->toUnicode(data);
-    return s;
+    return data;
+}
+
+void QWrk::processMarkers()
+{
+    int num = read32bit();
+    for (int i = 0; (i < num) && (d->internalFilePos() < d->m_lastChunkPos) && !atEnd(); ++i) {
+        int smpte = readByte();
+        readGap(1);
+        long time = read24bit();
+        readGap(5);
+        int len = readByte();
+        if (d->m_codec == nullptr) {
+            QByteArray data = readByteArray(len);
+            Q_EMIT signalWRKMarker2(time, smpte, data);
+        } else {
+            QString name = readString(len);
+            Q_EMIT signalWRKMarker(time, smpte, name);
+        }
+    }
 }
 
 /**
@@ -594,7 +651,7 @@ QString QWrk::readVarString()
  */
 long QWrk::getFilePos()
 {
-    return d->m_IOStream->device()->pos();
+    return d->internalFilePos();
 }
 
 /**
@@ -603,7 +660,9 @@ long QWrk::getFilePos()
  */
 void QWrk::seek(qint64 pos)
 {
-    d->m_IOStream->device()->seek(pos);
+    if (!d->m_IOStream->device()->seek(pos)) {
+        //qDebug() << Q_FUNC_INFO << "Error, pos:" << pos;
+    }
 }
 
 /**
@@ -622,7 +681,7 @@ bool QWrk::atEnd()
 void QWrk::readGap(int size)
 {
     if ( size > 0)
-        seek( getFilePos() + size );
+        seek( d->internalFilePos() + size );
 }
 
 /**
@@ -652,6 +711,7 @@ void QWrk::processTrackChunk()
 {
     int namelen;
     QString name[2];
+    QByteArray data[2];
     int trackno;
     int channel;
     int pitch;
@@ -664,9 +724,13 @@ void QWrk::processTrackChunk()
     trackno = read16bit();
     for(int i=0; i<2; ++i) {
         namelen = readByte();
-        name[i] = readString(namelen);
+        if (d->m_codec == nullptr) {
+            data[i] = readByteArray(namelen);
+        } else {
+            name[i] = readString(namelen);
+        }
     }
-    channel = (qint8) readByte();
+    channel = readByte() & 0x0f;
     pitch = readByte();
     velocity = readByte();
     port = readByte();
@@ -674,10 +738,17 @@ void QWrk::processTrackChunk()
     selected = ((flags & 1) != 0);
     muted = ((flags & 2) != 0);
     loop = ((flags & 4) != 0);
-    Q_EMIT signalWRKTrack( name[0], name[1],
-                           trackno, channel, pitch,
-                           velocity, port, selected,
-                           muted, loop );
+    if (d->m_codec == nullptr) {
+        Q_EMIT signalWRKTrack2( data[0], data[1],
+                               trackno, channel, pitch,
+                               velocity, port, selected,
+                               muted, loop );
+    } else {
+        Q_EMIT signalWRKTrack( name[0], name[1],
+                               trackno, channel, pitch,
+                               velocity, port, selected,
+                               muted, loop );
+    }
 }
 
 void QWrk::processVarsChunk()
@@ -734,7 +805,7 @@ void QWrk::processNoteArray(int track, int events)
     int value = 0, type = 0, channel = 0, len = 0;
     QString text;
     QByteArray data;
-    for ( i = 0; (i < events) && !atEnd(); ++i ) {
+    for ( i = 0; (i < events) && (d->internalFilePos() < d->m_lastChunkPos) && !atEnd(); ++i ) {
         time = read24bit();
         status = readByte();
         dur = 0;
@@ -773,8 +844,13 @@ void QWrk::processNoteArray(int track, int events)
         } else if (status == 5) {
             int code = read16bit();
             len = read32bit();
-            text = readString(len);
-            Q_EMIT signalWRKExpression(track, time, code, text);
+            if (d->m_codec == nullptr) {
+                data = readByteArray(len);
+                Q_EMIT signalWRKExpression2(track, time, code, data);
+            } else {
+                text = readString(len);
+                Q_EMIT signalWRKExpression(track, time, code, text);
+            }
         } else if (status == 6) {
             int code = read16bit();
             dur = read16bit();
@@ -799,8 +875,13 @@ void QWrk::processNoteArray(int track, int events)
             Q_EMIT signalWRKSysex(0, QString(), false, 0, data);
         } else {
             len = read32bit();
-            text = readString(len);
-            Q_EMIT signalWRKText(track, time, status, text);
+            if (d->m_codec == nullptr) {
+                data = readByteArray(len);
+                Q_EMIT signalWRKText2(track, time, status, data);
+            } else {
+                text = readString(len);
+                Q_EMIT signalWRKText(track, time, status, text);
+            }
         }
     }
     if ((i < events) && atEnd()) {
@@ -816,7 +897,7 @@ void QWrk::processStreamChunk()
     quint8 status = 0, data1 = 0, data2 = 0;
     quint16 track = read16bit();
     int events = read16bit();
-    for ( i = 0; (i < events) && !atEnd(); ++i ) {
+    for ( i = 0; (i < events) && (d->internalFilePos() < d->m_lastChunkPos) && !atEnd(); ++i ) {
         time = read24bit();
         status = readByte();
         data1 = readByte();
@@ -1028,8 +1109,13 @@ void QWrk::processTimeFormat()
 void QWrk::processComments()
 {
     int len = read16bit();
-    QString text = readString(len);
-    Q_EMIT signalWRKComments(text);
+    if (d->m_codec == nullptr) {
+        QByteArray data = readByteArray(len);
+        Q_EMIT signalWRKComments2(data);
+    } else {
+        QString text = readString(len);
+        Q_EMIT signalWRKComments(text);
+    }
 }
 
 void QWrk::processVariableRecord(int max)
@@ -1038,8 +1124,12 @@ void QWrk::processVariableRecord(int max)
     QByteArray data;
     QString name = readVarString();
     readGap(31 - name.length());
-    for ( int i = 0; i < datalen; ++i )
+    for ( int i = 0; i < datalen; ++i ) {
         data += readByte();
+    }
+    while (data.endsWith('\0')) {
+        data.chop(1);
+    }
     Q_EMIT signalWRKVariableRecord(name, data);
 }
 
@@ -1050,6 +1140,8 @@ void QWrk::processUnknown(int id)
 
 void QWrk::processNewTrack()
 {
+    QByteArray data;
+    QString name;
     qint16 bank = -1;
     qint16 patch = -1;
     //qint16 vol = -1;
@@ -1063,7 +1155,11 @@ void QWrk::processNewTrack()
     bool loop = false;
     quint16 track = read16bit();
     quint8 len = readByte();
-    QString name = readString(len);
+    if (d->m_codec == nullptr) {
+        data = readByteArray(len);
+    } else {
+        name = readString(len);
+    }
     bank = read16bit();
     patch = read16bit();
     /*vol =*/ read16bit();
@@ -1074,7 +1170,11 @@ void QWrk::processNewTrack()
     port = readByte();
     channel = readByte();
     muted = (readByte() != 0);
-    Q_EMIT signalWRKNewTrack(name, track, channel, key, vel, port, selected, muted, loop);
+    if (d->m_codec == nullptr) {
+        Q_EMIT signalWRKNewTrack2(data, track, channel, key, vel, port, selected, muted, loop);
+    } else {
+        Q_EMIT signalWRKNewTrack(name, track, channel, key, vel, port, selected, muted, loop);
+    }
     if (bank > -1)
         Q_EMIT signalWRKTrackBank(track, bank);
     if (patch > -1) {
@@ -1096,21 +1196,38 @@ void QWrk::processTrackName()
 {
     int track = read16bit();
     int len = readByte();
-    QString name = readString(len);
-    Q_EMIT signalWRKTrackName(track, name);
+    if (d->m_codec == nullptr) {
+        QByteArray data = readByteArray(len);
+        Q_EMIT signalWRKTrackName2(track, data);
+    } else {
+        QString name = readString(len);
+        Q_EMIT signalWRKTrackName(track, name);
+    }
 }
 
 void QWrk::processStringTable()
 {
-    QStringList table;
-    int rows = read16bit();
-    for (int i = 0; i < rows; ++i) {
-        int len = readByte();
-        QString name = readString(len);
-        int idx = readByte();
-        table.insert(idx, name);
+    if (d->m_codec == nullptr) {
+        QList<QByteArray> table;
+        int rows = read16bit();
+        for (int i = 0; i < rows; ++i) {
+            int len = readByte();
+            QByteArray name = readByteArray(len);
+            /*int idx =*/ readByte();
+            table.insert(i, name);
+        }
+        Q_EMIT signalWRKStringTable2(table);
+    } else {
+        QStringList table;
+        int rows = read16bit();
+        for (int i = 0; i < rows; ++i) {
+            int len = readByte();
+            QString name = readString(len);
+            /*int idx =*/ readByte();
+            table.insert(i, name);
+        }
+        Q_EMIT signalWRKStringTable(table);
     }
-    Q_EMIT signalWRKStringTable(table);
 }
 
 void QWrk::processLyricsStream()
@@ -1144,13 +1261,22 @@ void QWrk::processTrackBank()
 void QWrk::processSegmentChunk()
 {
     QString name;
+    QByteArray data;
     int track = read16bit();
     int offset = read32bit();
     readGap(8);
     int len = readByte();
-    name = readString(len);
+    if (d->m_codec == nullptr) {
+        data = readByteArray(len);
+    } else {
+        name = readString(len);
+    }
     readGap(20);
-    Q_EMIT signalWRKSegment(track, offset, name);
+    if (d->m_codec == nullptr) {
+        Q_EMIT signalWRKSegment2(track, offset, data);
+    } else {
+        Q_EMIT signalWRKSegment(track, offset, name);
+    }
     int events = read32bit();
     processNoteArray(track, events);
 }
@@ -1158,10 +1284,16 @@ void QWrk::processSegmentChunk()
 void QWrk::processNewStream()
 {
     QString name;
+    QByteArray data;
     int track = read16bit();
     int len = readByte();
-    name = readString(len);
-    Q_EMIT signalWRKSegment(track, 0, name);
+    if (d->m_codec == nullptr) {
+        data = readByteArray(len);
+        Q_EMIT signalWRKSegment2(track, 0, data);
+    } else {
+        name = readString(len);
+        Q_EMIT signalWRKSegment(track, 0, name);
+    }
     int events = read32bit();
     processNoteArray(track, events);
 }
@@ -1173,12 +1305,17 @@ void QWrk::processEndChunk()
 
 int QWrk::readChunk()
 {
-    long start_pos, final_pos;
-    int ck_len, ck = readByte();
+    qint64 start_pos = d->internalFilePos();
+    int ck = readByte();
     if (ck != END_CHUNK) {
-        ck_len = read32bit();
-        start_pos = getFilePos();
-        final_pos = start_pos + ck_len;
+        quint32 ck_len = read32bit();
+        if (ck_len > d->m_IOStream->device()->bytesAvailable()) {
+            Q_EMIT signalWRKError("Corrupted file");
+            seek(start_pos);
+            return END_CHUNK;
+        }
+        start_pos = d->internalFilePos();
+        d->m_lastChunkPos = start_pos + ck_len;
         readRawData(ck_len);
         seek(start_pos);
         switch (ck) {
@@ -1266,35 +1403,53 @@ int QWrk::readChunk()
         case NSTREAM_CHUNK:
             processNewStream();
             break;
+        case MARKERS_CHUNK:
+            processMarkers();
+            break;
         default:
             processUnknown(ck);
         }
-        seek(final_pos);
+        if (d->internalFilePos() != d->m_lastChunkPos) {
+            //qDebug() << Q_FUNC_INFO << "Current pos:" << d->internalFilePos() << "should be:" << d->m_lastChunkPos;
+            seek(d->m_lastChunkPos);
+        }
     }
     return ck;
 }
 
 void QWrk::wrkRead()
 {
-    int vma, vme;
-    int ck_id;
     QByteArray hdr(HEADER.length(), ' ');
     d->m_tempos.clear();
     d->m_IOStream->device()->read(hdr.data(), HEADER.length());
     if (hdr == HEADER) {
+        int vma, vme;
+        int ck_id;
         readGap(1);
         vme = readByte();
         vma = readByte();
         Q_EMIT signalWRKHeader(vma, vme);
         do {
             ck_id = readChunk();
-        }  while (ck_id != END_CHUNK);
-        if (!atEnd())
-            Q_EMIT signalWRKError("Corrupted file");
-        else
-            processEndChunk();
+        }  while ((ck_id != END_CHUNK) && !atEnd());
+        if (!atEnd()) {
+            //qDebug() << Q_FUNC_INFO << "extra junk past the end at" << d->internalFilePos();
+            readRawData(d->m_IOStream->device()->bytesAvailable());
+            processUnknown(ck_id);
+        }
+        processEndChunk();
     } else
         Q_EMIT signalWRKError("Invalid file format");
 }
 
+qint64 QWrk::QWrkPrivate::internalFilePos()
+{
+    return m_IOStream->device()->pos();
+}
+
+const QByteArray QWrk::HEADER = QByteArrayLiteral("CAKEWALK");
+
+} // namespace File
 } // namespace drumstick
+
+DISABLE_WARNING_POP
