@@ -1,6 +1,6 @@
 /*
     Standard MIDI File component
-    Copyright (C) 2006-2021, Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2006-2022, Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     Based on midifile.c by Tim Thompson, M.Czeiszperger and Greg Lee
 
@@ -24,8 +24,8 @@
 #include "macros.h"
 #include <QObject>
 #include <QScopedPointer>
-#include <QTextCodec>
 
+class QTextCodec;
 class QDataStream;
 
 /**
@@ -128,8 +128,8 @@ public:
     void setTracks(int tracks);
     int  getFileFormat();
     void setFileFormat(int fileFormat);
-    QTextCodec* getTextCodec();
-    void setTextCodec(QTextCodec *codec);
+    Q_DECL_DEPRECATED QTextCodec* getTextCodec();
+    Q_DECL_DEPRECATED void setTextCodec(QTextCodec *codec);
 
 signals:
     /**
@@ -232,8 +232,16 @@ signals:
      * Emitted after reading a SMF text message
      * @param typ Text type
      * @param data Text data
+     * @deprecated because the class QTextCodec was removed from QtCore since Qt6.
+     * use signalSMFText2() instead.
      */
-    void signalSMFText(int typ, const QString& data);
+    Q_DECL_DEPRECATED void signalSMFText(int typ, const QString& data);
+    /**
+     * Emitted after reading a SMF text message
+     * @param typ Text type
+     * @param data Text data
+     */
+    void signalSMFText2(int typ, const QByteArray& data);
     /**
      * Emitted after reading a SMPT offset message
      * @param b0 Hours
