@@ -1,10 +1,10 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -16,12 +16,17 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QUdpSocket>
 #include "netmidiinput.h"
 #include "netmidiinput_p.h"
+#include <QUdpSocket>
 
-namespace drumstick {
-namespace rt {
+namespace drumstick { namespace rt {
+
+const QString NetMIDIInput::DEFAULT_PUBLIC_NAME = QStringLiteral("MIDI In");
+const QString NetMIDIInput::STR_ADDRESS_IPV4 = QStringLiteral("225.0.0.37");
+const QString NetMIDIInput::STR_ADDRESS_IPV6 = QStringLiteral("ff12::37");
+const int NetMIDIInput::MULTICAST_PORT = 21928;
+const int NetMIDIInput::LAST_PORT = 21948;
 
 NetMIDIInput::NetMIDIInput(QObject *parent):
     MIDIInput(parent),
@@ -35,7 +40,7 @@ void NetMIDIInput::initialize(QSettings *settings)
 
 QString NetMIDIInput::backendName()
 {
-    return QLatin1String("Network");
+    return QStringLiteral("Network");
 }
 
 QString NetMIDIInput::publicName()
@@ -48,7 +53,7 @@ void NetMIDIInput::setPublicName(QString name)
     d->m_publicName = name;
 }
 
-QStringList NetMIDIInput::connections(bool advanced)
+QList<MIDIConnection> NetMIDIInput::connections(bool advanced)
 {
     Q_UNUSED(advanced)
     return d->m_inputDevices;
@@ -59,7 +64,7 @@ void NetMIDIInput::setExcludedConnections(QStringList conns)
     d->m_excludedNames = conns;
 }
 
-void NetMIDIInput::open(QString name)
+void NetMIDIInput::open(const MIDIConnection& name)
 {
     d->open(name);
 }
@@ -69,7 +74,7 @@ void NetMIDIInput::close()
     d->close();
 }
 
-QString NetMIDIInput::currentConnection()
+MIDIConnection NetMIDIInput::currentConnection()
 {
     return d->m_currentInput;
 }
@@ -86,8 +91,19 @@ void NetMIDIInput::enableMIDIThru(bool enable)
 
 bool NetMIDIInput::isEnabledMIDIThru()
 {
-    return d->m_thruEnabled && (d->m_out != 0);
+    return d->m_thruEnabled && (d->m_out != nullptr);
 }
 
-}}
+QStringList NetMIDIInput::getDiagnostics()
+{
+    return d->m_diagnostics;
+}
+
+bool NetMIDIInput::getStatus()
+{
+    return d->m_status;
+}
+
+} // namespace rt
+} // namespace drumstick
 
