@@ -1,10 +1,10 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -17,15 +17,11 @@
 */
 
 #include <QObject>
-#include <QDebug>
 
-#include "netmidiinput_p.h"
 #include "netmidiinput.h"
+#include "netmidiinput_p.h"
 
-namespace drumstick {
-namespace rt {
-
-static QString DEFAULT_PUBLIC_NAME(QLatin1String("MIDI In"));
+namespace drumstick { namespace rt {
 
 NetMIDIInputPrivate::NetMIDIInputPrivate(QObject *parent) : QObject(parent),
     m_inp(qobject_cast<NetMIDIInput *>(parent)),
@@ -34,24 +30,25 @@ NetMIDIInputPrivate::NetMIDIInputPrivate(QObject *parent) : QObject(parent),
     m_parser(nullptr),
     m_thruEnabled(false),
     m_port(0),
-    m_publicName(DEFAULT_PUBLIC_NAME),
-    m_groupAddress(QHostAddress(STR_ADDRESS_IPV4)),
-    m_ipv6(false)
+    m_publicName(NetMIDIInput::DEFAULT_PUBLIC_NAME),
+    m_groupAddress(QHostAddress(NetMIDIInput::STR_ADDRESS_IPV4)),
+    m_ipv6(false),
+    m_status(false)
 {
-    for(int i=MULTICAST_PORT; i<LAST_PORT; ++i) {
-        m_inputDevices << QString::number(i);
+    for(int i=NetMIDIInput::MULTICAST_PORT; i<NetMIDIInput::LAST_PORT; ++i) {
+        m_inputDevices << MIDIConnection(QString::number(i), i);
     }
 }
 
-void NetMIDIInputPrivate::open(QString portName)
+void NetMIDIInputPrivate::open(const MIDIConnection& portName)
 {
-    int p = m_inputDevices.indexOf(portName);
-    if (p > -1)
+    int p = portName.second.toInt();
+    if (p >= NetMIDIInput::MULTICAST_PORT && p < NetMIDIInput::LAST_PORT && m_status)
     {
         //qDebug() << Q_FUNC_INFO << portName;
         m_socket = new QUdpSocket();
         m_parser = new MIDIParser(m_inp);
-        m_port = static_cast<quint16>(MULTICAST_PORT + p);
+        m_port = static_cast<quint16>(p);
         m_currentInput = portName;
         bool res = m_socket->bind(m_ipv6 ? QHostAddress::AnyIPv6 : QHostAddress::AnyIPv4, m_port, QUdpSocket::ShareAddress);
         if (res) {
@@ -64,10 +61,11 @@ void NetMIDIInputPrivate::open(QString portName)
             } else {
                 res = m_socket->joinMulticastGroup(m_groupAddress);
             }
-            connect(m_socket, SIGNAL(readyRead()), this, SLOT(processIncomingMessages()));
-        }
-        if (!res) {
-            qWarning() << "Socket error. err:" << m_socket->error() << m_socket->errorString();
+            connect(m_socket, &QUdpSocket::readyRead, this, &NetMIDIInputPrivate::processIncomingMessages);
+            m_status = m_socket->isValid();
+        } else {
+            m_status = false;
+            m_diagnostics << QString("Socket error. err: %1 = %2").arg(m_socket->error()).arg(m_socket->errorString());
         }
     }
 }
@@ -78,25 +76,33 @@ void NetMIDIInputPrivate::close()
     delete m_parser;
     m_socket = nullptr;
     m_parser = nullptr;
-    m_currentInput.clear();
+    m_currentInput = MIDIConnection();
+    m_status = false;
+    m_diagnostics.clear();
 }
 
 void NetMIDIInputPrivate::initialize(QSettings *settings)
 {
     if (settings != nullptr) {
+        m_status = false;
+        m_diagnostics.clear();
         settings->beginGroup("Network");
         QString ifaceName = settings->value("interface", QString()).toString();
         m_ipv6 = settings->value("ipv6", false).toBool();
-        QString address = settings->value("address", m_ipv6 ? STR_ADDRESS_IPV6 : STR_ADDRESS_IPV4).toString();
+        QString address = settings->value("address", m_ipv6 ? NetMIDIInput::STR_ADDRESS_IPV6 : NetMIDIInput::STR_ADDRESS_IPV4).toString();
         settings->endGroup();
         if (!ifaceName.isEmpty()) {
             m_iface = QNetworkInterface::interfaceFromName(ifaceName);
         }
         if (address.isEmpty()) {
-            m_groupAddress.setAddress(m_ipv6 ? STR_ADDRESS_IPV6 : STR_ADDRESS_IPV4);
+            m_groupAddress.setAddress(m_ipv6 ? NetMIDIInput::STR_ADDRESS_IPV6 : NetMIDIInput::STR_ADDRESS_IPV4);
         } else {
             m_groupAddress.setAddress(address);
         }
+        m_status = m_groupAddress.isMulticast();
+        if (!m_status) {
+            m_diagnostics << QString("Invalid multicast address: %1").arg(address);
+        }
     }
 }
 
@@ -120,4 +126,5 @@ void NetMIDIInputPrivate::processIncomingMessages()
     }
 }
 
-}}
+} // namespace rt
+} // namespace drumstick
