@@ -1,10 +1,10 @@
 /*
     Drumstick RT (realtime MIDI In/Out)
-    Copyright (C) 2009-2019 Pedro Lopez-Cabanillas <plcl@users.sf.net>
+    Copyright (C) 2009-2022 Pedro Lopez-Cabanillas <plcl@users.sf.net>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -16,16 +16,18 @@
     along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QDebug>
-#include <QUdpSocket>
+#include "netmidioutput.h"
 #include <QNetworkInterface>
 #include <QSettings>
-#include "netmidioutput.h"
+#include <QUdpSocket>
 
-namespace drumstick {
-namespace rt {
+namespace drumstick { namespace rt {
 
-static QString DEFAULT_PUBLIC_NAME(QLatin1String("MIDI Out"));
+const QString NetMIDIOutput::DEFAULT_PUBLIC_NAME = QStringLiteral("MIDI Out");
+const QString NetMIDIOutput::STR_ADDRESS_IPV4 = QStringLiteral("225.0.0.37");
+const QString NetMIDIOutput::STR_ADDRESS_IPV6 = QStringLiteral("ff12::37");
+const int NetMIDIOutput::MULTICAST_PORT = 21928;
+const int NetMIDIOutput::LAST_PORT = 21948;
 
 class NetMIDIOutput::NetMIDIOutputPrivate
 {
@@ -33,12 +35,14 @@ public:
     QUdpSocket *m_socket;
     QString m_publicName;
     QHostAddress m_groupAddress;
-    QString m_currentOutput;
-    QStringList m_outputDevices;
+    MIDIConnection m_currentOutput;
+    QList<MIDIConnection> m_outputDevices;
     QStringList m_excludedNames;
     QNetworkInterface m_iface;
     quint16 m_port;
     bool m_ipv6;
+    bool m_status;
+    QStringList m_diagnostics;
 
     NetMIDIOutputPrivate() :
         m_socket(nullptr),
@@ -48,7 +52,7 @@ public:
         m_ipv6(false)
     {
         for(int i=MULTICAST_PORT; i<LAST_PORT; ++i) {
-            m_outputDevices << QString::number(i);
+            m_outputDevices << MIDIConnection(QString::number(i), i);
         }
     }
 
@@ -60,6 +64,8 @@ public:
     void initialize(QSettings* settings)
     {
         if (settings != nullptr) {
+            m_status = false;
+            m_diagnostics.clear();
             settings->beginGroup("Network");
             QString ifaceName = settings->value("interface", QString()).toString();
             m_ipv6 = settings->value("ipv6", false).toBool();
@@ -73,14 +79,18 @@ public:
             } else {
                 m_groupAddress.setAddress(address);
             }
+            m_status = m_groupAddress.isMulticast();
+            if (!m_status) {
+                m_diagnostics << QString("Invalid multicast address: %1").arg(address);
+            }
         }
     }
 
-    void open(QString portName)
+    void open(const MIDIConnection& portName)
     {
-        qDebug() << Q_FUNC_INFO << portName;
-        int p = m_outputDevices.indexOf(portName);
-        if (p > -1)
+        //qDebug() << Q_FUNC_INFO << portName;
+        int p = portName.second.toInt();
+        if (p >= MULTICAST_PORT && p < LAST_PORT && m_status)
         {
             m_socket = new QUdpSocket();
             bool res = m_socket->bind(m_ipv6 ? QHostAddress::AnyIPv6 : QHostAddress::AnyIPv4, m_socket->localPort());
@@ -89,14 +99,15 @@ public:
 #ifdef Q_OS_UNIX
                 m_socket->setSocketOption(QAbstractSocket::MulticastLoopbackOption, 0);
 #endif
-                m_port = static_cast<quint16>(MULTICAST_PORT + p);
+                m_port = static_cast<quint16>(p);
                 if (m_iface.isValid()) {
                     m_socket->setMulticastInterface(m_iface);
                 }
                 m_currentOutput = portName;
-            }
-            if (!res) {
-                qWarning() << Q_FUNC_INFO << "Socket error:" << m_socket->error() << m_socket->errorString();
+                m_status = m_socket->isValid();
+            } else {
+                m_status = false;
+                m_diagnostics << QString("Socket error: %1 = %2").arg(m_socket->error()).arg(m_socket->errorString());
             }
         }
     }
@@ -105,7 +116,9 @@ public:
     {
         delete m_socket;
         m_socket = nullptr;
-        m_currentOutput.clear();
+        m_currentOutput = MIDIConnection();
+        m_status = false;
+        m_diagnostics.clear();
     }
 
     void sendMessage(int m0)
@@ -139,16 +152,16 @@ public:
     {
         //qDebug() << Q_FUNC_INFO << message.toHex() << m_groupAddress << m_port;
         if (m_socket == nullptr) {
-            qWarning() << Q_FUNC_INFO << "udp socket is null";
+            m_diagnostics << "udp socket is null";
             return;
         } else if (!m_socket->isValid() || m_socket->state() != QAbstractSocket::BoundState) {
-            qWarning() << Q_FUNC_INFO << "udp socket has invalid state:" << m_socket->state() << "Error:" << m_socket->error() << m_socket->errorString();
+            m_diagnostics << QString("udp socket has invalid state: %1 Error: %2 %3").arg(m_socket->state()).arg(m_socket->error()).arg(m_socket->errorString());
             return;
         }
         auto res = m_socket->writeDatagram(message, m_groupAddress, m_port);
         //qDebug() << Q_FUNC_INFO << "writeDatagram:" << res;
         if (res < 0) {
-            qWarning() << Q_FUNC_INFO << "Error:" << m_socket->error() << m_socket->errorString();
+            m_diagnostics << QString("Error: %1 %2").arg(m_socket->error()).arg(m_socket->errorString());
         }
     }
 };
@@ -169,7 +182,7 @@ void NetMIDIOutput::initialize(QSettings *settings)
 
 QString NetMIDIOutput::backendName()
 {
-    return QLatin1String("Network");
+    return QStringLiteral("Network");
 }
 
 QString NetMIDIOutput::publicName()
@@ -182,7 +195,7 @@ void NetMIDIOutput::setPublicName(QString name)
     d->m_publicName = name;
 }
 
-QStringList NetMIDIOutput::connections(bool advanced)
+QList<MIDIConnection> NetMIDIOutput::connections(bool advanced)
 {
     Q_UNUSED(advanced)
     return d->m_outputDevices;
@@ -193,7 +206,7 @@ void NetMIDIOutput::setExcludedConnections(QStringList conns)
     Q_UNUSED(conns)
 }
 
-void NetMIDIOutput::open(QString name)
+void NetMIDIOutput::open(const MIDIConnection& name)
 {
     d->open(name);
 }
@@ -203,7 +216,7 @@ void NetMIDIOutput::close()
     d->close();
 }
 
-QString NetMIDIOutput::currentConnection()
+MIDIConnection NetMIDIOutput::currentConnection()
 {
     return d->m_currentOutput;
 }
@@ -255,5 +268,16 @@ void NetMIDIOutput::sendSystemMsg(const int status)
     d->sendMessage(status);
 }
 
-}}
+QStringList NetMIDIOutput::getDiagnostics()
+{
+    return d->m_diagnostics;
+}
+
+bool NetMIDIOutput::getStatus()
+{
+    return d->m_status;
+}
+
+} // namespace rt
+} // namespace drumstick
 
