@@ -23,6 +23,7 @@
 #include <QStandardPaths>
 #include <QToolButton>
 #include <QMessageBox>
+#include <QVersionNumber>
 
 #include "fluidsettingsdialog.h"
 #include "ui_fluidsettingsdialog.h"
@@ -40,7 +41,6 @@ const QString FluidSettingsDialog::QSTR_PREFERENCES = QStringLiteral("FluidSynth
 const QString FluidSettingsDialog::QSTR_INSTRUMENTSDEFINITION = QStringLiteral("InstrumentsDefinition");
 const QString FluidSettingsDialog::QSTR_DATADIR = QStringLiteral("soundfonts");
 const QString FluidSettingsDialog::QSTR_DATADIR2 = QStringLiteral("sounds/sf2");
-const QString FluidSettingsDialog::QSTR_SOUNDFONT = QStringLiteral("default.sf2");
 const QString FluidSettingsDialog::QSTR_AUDIODRIVER = QStringLiteral("AudioDriver");
 const QString FluidSettingsDialog::QSTR_PERIODSIZE = QStringLiteral("PeriodSize");
 const QString FluidSettingsDialog::QSTR_PERIODS = QStringLiteral("Periods");
@@ -85,6 +85,10 @@ FluidSettingsDialog::FluidSettingsDialog(QWidget *parent) :
             ui->audioDriver->addItems(v.toStringList());
             ui->audioDriver->blockSignals(false);
         }
+        v = m_driver->property("soundfont");
+        if (v.isValid()) {
+            m_defSoundFont = v.toString();
+        }
     }
     ui->bufferTime->blockSignals(true);
     ui->periodSize->blockSignals(true);
@@ -195,11 +199,8 @@ void FluidSettingsDialog::chkDriverProperties(QSettings *settings)
             ui->audioDriver->setCurrentText(text);
             ui->audioDriver->blockSignals(false);
         }
-        QVariant varVersion = m_driver->property("libversion");
-        if (varVersion.isValid()) {
-            ui->lblVersion->clear();
-            ui->lblVersion->setText(varVersion.toString());
-        }
+        ui->lblVersion->clear();
+        ui->lblVersion->setText(driverVersion());
         QVariant varStatus = m_driver->property("status");
         if (varStatus.isValid()) {
             ui->lblStatus->clear();
@@ -211,13 +212,10 @@ void FluidSettingsDialog::chkDriverProperties(QSettings *settings)
 
 void drumstick::widgets::FluidSettingsDialog::initBuffer()
 {
-    if (ui->audioDriver->currentText() == QSTR_PULSEAUDIO) {
-        //qDebug() << Q_FUNC_INFO << QSTR_PULSEAUDIO;
+    if ((ui->audioDriver->currentText() == QSTR_PULSEAUDIO) && driverVersionLessThan_2_2_8()) {
+        //qDebug() << Q_FUNC_INFO << QSTR_PULSEAUDIO << driverVersion();
         int bufferTime = ui->bufferTime->value();
         int minBufTime = ui->bufferTime->minimum();
-        if (qEnvironmentVariableIsSet("PULSE_LATENCY_MSEC")) {
-            bufferTime = qEnvironmentVariable("PULSE_LATENCY_MSEC").toInt();
-        }
         if (bufferTime < minBufTime) {
             bufferTime = minBufTime;
         }
@@ -229,20 +227,29 @@ void drumstick::widgets::FluidSettingsDialog::initBuffer()
     }
 }
 
+QString FluidSettingsDialog::driverVersion() const
+{
+    static QString result;
+    if (m_driver != nullptr && result.isEmpty()) {
+        QVariant varVersion = m_driver->property("libversion");
+        if (varVersion.isValid()) {
+            result = varVersion.toString();
+        }
+    }
+    return result;
+}
+
+bool FluidSettingsDialog::driverVersionLessThan_2_2_8()
+{
+    static const QVersionNumber check_2_2_8(2, 2, 8);
+    QVersionNumber driverV = QVersionNumber::fromString(driverVersion());
+    return driverV < check_2_2_8;
+}
+
 void FluidSettingsDialog::readSettings()
 {
     //qDebug() << Q_FUNC_INFO;
     SettingsFactory settings;
-    QString fs_defSoundFont = QSTR_SOUNDFONT;
-    QDir dir(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QSTR_DATADIR, QStandardPaths::LocateDirectory));
-    if (!dir.exists()) {
-        dir = QDir(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QSTR_DATADIR2, QStandardPaths::LocateDirectory));
-    }
-    QFileInfo sf2(dir, QSTR_SOUNDFONT);
-    if (sf2.exists()) {
-        fs_defSoundFont = sf2.absoluteFilePath();
-    }
-
     settings->beginGroup(QSTR_PREFERENCES);
     ui->audioDriver->setCurrentText( settings->value(QSTR_AUDIODRIVER, defaultAudioDriver()).toString() );
     ui->bufferTime->setValue( settings->value(QSTR_BUFFERTIME, DEFAULT_BUFFERTIME).toInt() );
@@ -253,7 +260,7 @@ void FluidSettingsDialog::readSettings()
     ui->reverb->setChecked( settings->value(QSTR_REVERB, DEFAULT_REVERB).toInt() != 0 );
     ui->gain->setText( settings->value(QSTR_GAIN, DEFAULT_GAIN).toString() );
     ui->polyphony->setText( settings->value(QSTR_POLYPHONY, DEFAULT_POLYPHONY).toString() );
-    ui->soundFont->setText( settings->value(QSTR_INSTRUMENTSDEFINITION, fs_defSoundFont).toString() );
+    ui->soundFont->setText( settings->value(QSTR_INSTRUMENTSDEFINITION, m_defSoundFont).toString() );
     settings->endGroup();
 
     audioDriverChanged( ui->audioDriver->currentText() );
@@ -265,7 +272,7 @@ void FluidSettingsDialog::writeSettings()
     //qDebug() << Q_FUNC_INFO;
     SettingsFactory settings;
     QString audioDriver;
-    QString soundFont(QSTR_SOUNDFONT);
+    QString soundFont(m_defSoundFont);
     int     bufferTime(DEFAULT_BUFFERTIME);
     int     periodSize(DEFAULT_PERIODSIZE);
     int     periods(DEFAULT_PERIODS);
@@ -303,9 +310,6 @@ void FluidSettingsDialog::writeSettings()
     settings->endGroup();
     settings->sync();
 
-    if ( audioDriver == QSTR_PULSEAUDIO ) {
-        qputenv("PULSE_LATENCY_MSEC", QByteArray::number( bufferTime ) );
-    }
     chkDriverProperties(settings.getQSettings());
 }
 
@@ -321,7 +325,7 @@ void FluidSettingsDialog::restoreDefaults()
     ui->reverb->setChecked( DEFAULT_REVERB != 0 );
     ui->gain->setText( QString::number( DEFAULT_GAIN ) );
     ui->polyphony->setText( QString::number( DEFAULT_POLYPHONY ));
-    ui->soundFont->setText( QSTR_SOUNDFONT );
+    ui->soundFont->setText( m_defSoundFont );
     initBuffer();
 }
 
@@ -340,11 +344,12 @@ void FluidSettingsDialog::showFileDialog()
 void FluidSettingsDialog::audioDriverChanged(const QString &text)
 {
     //qDebug() << Q_FUNC_INFO << text;
-    if (text == QSTR_PULSEAUDIO) {
+    if ((text == QSTR_PULSEAUDIO) && driverVersionLessThan_2_2_8()) {
         ui->bufferTime->setDisabled(false);
         ui->bufferTime->blockSignals(false);
         ui->periodSize->setDisabled(true);
         ui->periodSize->blockSignals(true);
+        ui->periods->setVisible(false);
         ui->periods->setDisabled(true);
         ui->periods->blockSignals(true);
     } else {
@@ -352,6 +357,7 @@ void FluidSettingsDialog::audioDriverChanged(const QString &text)
         ui->bufferTime->blockSignals(true);
         ui->periodSize->setDisabled(false);
         ui->periodSize->blockSignals(false);
+        ui->periods->setVisible(true);
         ui->periods->setDisabled(false);
         ui->periods->blockSignals(false);
     }
@@ -372,7 +378,7 @@ void FluidSettingsDialog::bufferSizeChanged()
     QString audioDriver = ui->audioDriver->currentText();
     double rate = ui->sampleRate->text().toDouble();
     int size = ui->periodSize->value();
-    if (audioDriver != QSTR_PULSEAUDIO) {
+    if ((audioDriver != QSTR_PULSEAUDIO) || !driverVersionLessThan_2_2_8()) {
         size *= ui->periods->value();
     }
     int ms = qRound( 1000.0 * size / rate );
