@@ -375,7 +375,7 @@
     <message>
         <location filename="../fluidsettingsdialog.cpp" line="345"/>
         <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
-        <translation type="unfinished"></translation>
+        <translation>Ficheiros SoundFont (*.sf2 *.sf3 *.dls)</translation>
     </message>
     <message>
         <source>SoundFont Files (*.sf2)</source>
