@@ -42,11 +42,18 @@ int main(int argc, char *argv[])
     QCoreApplication::setOrganizationDomain(QSTR_DOMAIN);
     QCoreApplication::setApplicationName(QSTR_APPNAME);
     QCoreApplication::setApplicationVersion(QStringLiteral(QT_STRINGIFY(VERSION)));
+    QGuiApplication::setDesktopFileName("net.sourceforge.drumstick-drumgrid");
 
     QLocale locale;
     QTranslator qtTranslator;
     if ((locale.language() != QLocale::C) && (locale.language() != QLocale::English)) {
-        if (qtTranslator.load(locale, "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath))) {
+        if (qtTranslator.load( locale, "qt", "_",
+            #if QT_VERSION < QT_VERSION_CHECK(6,0,0)
+                               QLibraryInfo::location(QLibraryInfo::TranslationsPath)
+            #else
+                               QLibraryInfo::path(QLibraryInfo::TranslationsPath)
+            #endif
+                              )) {
             QCoreApplication::installTranslator(&qtTranslator);
         } else {
             qWarning() << "Unable to load Qt translator:" << locale.name();
