@@ -37,7 +37,7 @@
 #include <drumstick/alsaqueue.h>
 #include <drumstick/subscription.h>
 
-class QDumpMIDI : public QObject
+class QDumpMIDI : public QObject, public drumstick::ALSA::SequencerEventHandler
 {
     Q_OBJECT
 public:
@@ -50,6 +50,8 @@ public:
     bool stopped();
     void run();
 
+    virtual void handleSequencerEvent(drumstick::ALSA::SequencerEvent* ev);
+
 public slots:
     void subscription( drumstick::ALSA::MidiPort* port, drumstick::ALSA::Subscription* subs );
 
