@@ -200,172 +200,199 @@ p, li { white-space: pre-wrap; }
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="51"/>
+        <location filename="vpiano.ui" line="56"/>
         <source>Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="58"/>
+        <location filename="vpiano.ui" line="63"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="62"/>
+        <location filename="vpiano.ui" line="67"/>
         <source>Show Note Names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="71"/>
+        <location filename="vpiano.ui" line="76"/>
         <source>Black Keys Names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="79"/>
+        <location filename="vpiano.ui" line="84"/>
         <source>Names Orientation</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="87"/>
-        <source>Central Octave Name</source>
+        <location filename="vpiano.ui" line="92"/>
+        <source>Central Octave C Note Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="96"/>
+        <location filename="vpiano.ui" line="101"/>
         <source>Note Names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="122"/>
+        <location filename="vpiano.ui" line="128"/>
         <source>&amp;Exit</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="127"/>
+        <location filename="vpiano.ui" line="133"/>
         <source>&amp;Preferences</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="132"/>
+        <location filename="vpiano.ui" line="138"/>
         <source>&amp;Connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="137"/>
+        <location filename="vpiano.ui" line="143"/>
         <source>About</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="142"/>
+        <location filename="vpiano.ui" line="148"/>
         <source>About Qt</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="153"/>
+        <location filename="vpiano.ui" line="159"/>
         <source>Never</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="161"/>
+        <location filename="vpiano.ui" line="167"/>
         <source>When Activated</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="169"/>
+        <location filename="vpiano.ui" line="175"/>
         <source>Always</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="180"/>
+        <location filename="vpiano.ui" line="186"/>
         <source>Sharps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="191"/>
+        <location filename="vpiano.ui" line="197"/>
         <source>Flats</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="199"/>
+        <location filename="vpiano.ui" line="205"/>
         <source>Nothing</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="210"/>
+        <location filename="vpiano.ui" line="216"/>
         <source>Horizontal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="218"/>
+        <location filename="vpiano.ui" line="224"/>
         <source>Vertical</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="226"/>
+        <location filename="vpiano.ui" line="232"/>
         <source>Automatic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="231"/>
+        <location filename="vpiano.ui" line="237"/>
         <source>Names Font</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="239"/>
+        <location filename="vpiano.ui" line="245"/>
         <source>Minimal</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="247"/>
+        <location filename="vpiano.ui" line="253"/>
+        <location filename="vpiano.ui" line="256"/>
+        <location filename="vpiano.ui" line="259"/>
         <source>C3</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="258"/>
+        <location filename="vpiano.ui" line="270"/>
         <source>C4</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="266"/>
+        <location filename="vpiano.ui" line="278"/>
         <source>C5</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="277"/>
+        <location filename="vpiano.ui" line="289"/>
         <source>Standard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="285"/>
+        <location filename="vpiano.ui" line="297"/>
         <source>Custom with Sharps</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="293"/>
+        <location filename="vpiano.ui" line="305"/>
         <source>Custom with Flats</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="301"/>
+        <location filename="vpiano.ui" line="313"/>
         <source>C</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="309"/>
+        <location filename="vpiano.ui" line="321"/>
         <source>Inverted Keys Color</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="461"/>
+        <location filename="vpiano.ui" line="329"/>
+        <source>Raw Computer Keyboard</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="340"/>
+        <source>Computer  Keyboard Input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="348"/>
+        <source>Mouse Input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="356"/>
+        <source>Touch Screen Input</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="364"/>
+        <source>Octave Subscript Designation</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="vpiano.cpp" line="459"/>
         <source>Font to display note names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="537"/>
+        <location filename="vpiano.cpp" line="535"/>
         <source>Custom Note Names</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="537"/>
+        <location filename="vpiano.cpp" line="535"/>
         <source>Names:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -380,12 +407,12 @@ This program comes with ABSOLUTELY NO WARRANTY; This is free software, and you a
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpianomain.cpp" line="124"/>
+        <location filename="vpianomain.cpp" line="131"/>
         <source>Portable settings mode</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="vpianomain.cpp" line="138"/>
+        <location filename="vpianomain.cpp" line="145"/>
         <source>Fatal error from a MIDI backend.</source>
         <translation type="unfinished"></translation>
     </message>
