@@ -241,172 +241,203 @@ redistribuirlo bajo ciertas condiciones.</translation>
         <translation>Edición</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="51"/>
+        <location filename="vpiano.ui" line="56"/>
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="58"/>
+        <location filename="vpiano.ui" line="63"/>
         <source>View</source>
         <translation>Ver</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="62"/>
+        <location filename="vpiano.ui" line="67"/>
         <source>Show Note Names</source>
         <translation>Mostrar nombres de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="71"/>
+        <location filename="vpiano.ui" line="76"/>
         <source>Black Keys Names</source>
         <translation>Nombres de las teclas negras</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="79"/>
+        <location filename="vpiano.ui" line="84"/>
         <source>Names Orientation</source>
         <translation>Orientación de los nombres</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="87"/>
         <source>Central Octave Name</source>
-        <translation>Nombre de la octava central</translation>
+        <translation type="vanished">Nombre de la octava central</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="96"/>
+        <location filename="vpiano.ui" line="92"/>
+        <source>Central Octave C Note Name</source>
+        <translation>Nombre del Do de la octava central</translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="101"/>
         <source>Note Names</source>
         <translation>Nombres de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="122"/>
+        <location filename="vpiano.ui" line="128"/>
         <source>&amp;Exit</source>
         <translation>&amp;Salir</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="127"/>
+        <location filename="vpiano.ui" line="133"/>
         <source>&amp;Preferences</source>
         <translation>&amp;Preferencias</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="132"/>
+        <location filename="vpiano.ui" line="138"/>
         <source>&amp;Connections</source>
         <translation>&amp;Conexiones</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="137"/>
+        <location filename="vpiano.ui" line="143"/>
         <source>About</source>
         <translation>Acerca de</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="142"/>
+        <location filename="vpiano.ui" line="148"/>
         <source>About Qt</source>
         <translation>Acerca de Qt</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="153"/>
+        <location filename="vpiano.ui" line="159"/>
         <source>Never</source>
         <translation>Nunca</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="161"/>
+        <location filename="vpiano.ui" line="167"/>
         <source>When Activated</source>
         <translation>Cuando se activen</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="169"/>
+        <location filename="vpiano.ui" line="175"/>
         <source>Always</source>
         <translation>Siempre</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="180"/>
+        <location filename="vpiano.ui" line="186"/>
         <source>Sharps</source>
         <translation>Sostenidos</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="191"/>
+        <location filename="vpiano.ui" line="197"/>
         <source>Flats</source>
         <translation>Bemoles</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="199"/>
+        <location filename="vpiano.ui" line="205"/>
         <source>Nothing</source>
         <translation>Nada</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="210"/>
+        <location filename="vpiano.ui" line="216"/>
         <source>Horizontal</source>
         <translation>Horizontal</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="218"/>
+        <location filename="vpiano.ui" line="224"/>
         <source>Vertical</source>
         <translation>Vertical</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="226"/>
+        <location filename="vpiano.ui" line="232"/>
         <source>Automatic</source>
         <translation>Automática</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="231"/>
+        <location filename="vpiano.ui" line="237"/>
         <source>Names Font</source>
         <translation>Fuente para  nombres</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="239"/>
+        <location filename="vpiano.ui" line="245"/>
         <source>Minimal</source>
         <translation>Mínimo</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="247"/>
+        <location filename="vpiano.ui" line="253"/>
+        <location filename="vpiano.ui" line="256"/>
+        <location filename="vpiano.ui" line="259"/>
         <source>C3</source>
         <translation>do3</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="258"/>
+        <location filename="vpiano.ui" line="270"/>
         <source>C4</source>
         <translation>do4</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="266"/>
+        <location filename="vpiano.ui" line="278"/>
         <source>C5</source>
         <translation>do5</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="277"/>
+        <location filename="vpiano.ui" line="289"/>
         <source>Standard</source>
         <translation>Estándar</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="285"/>
+        <location filename="vpiano.ui" line="297"/>
         <source>Custom with Sharps</source>
         <translation>Personalizadas con sostenidos</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="293"/>
+        <location filename="vpiano.ui" line="305"/>
         <source>Custom with Flats</source>
         <translation>Personalizadas con bemoles</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="301"/>
+        <location filename="vpiano.ui" line="313"/>
         <source>C</source>
         <translation>do</translation>
     </message>
     <message>
-        <location filename="vpiano.ui" line="309"/>
+        <location filename="vpiano.ui" line="321"/>
         <source>Inverted Keys Color</source>
         <translation>Teclas de color invertido</translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="461"/>
+        <location filename="vpiano.ui" line="329"/>
+        <source>Raw Computer Keyboard</source>
+        <translation>Teclado de ordenador de bajo nivel</translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="340"/>
+        <source>Computer  Keyboard Input</source>
+        <translation>Entrada por teclado de ordenador</translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="348"/>
+        <source>Mouse Input</source>
+        <translation>Entrada por ratón</translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="356"/>
+        <source>Touch Screen Input</source>
+        <translation>Entrada por pantalla táctil</translation>
+    </message>
+    <message>
+        <location filename="vpiano.ui" line="364"/>
+        <source>Octave Subscript Designation</source>
+        <translation>Designación de subíndice de octava</translation>
+    </message>
+    <message>
+        <location filename="vpiano.cpp" line="459"/>
         <source>Font to display note names</source>
         <translation>Fuente para mostrar nombres de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="537"/>
+        <location filename="vpiano.cpp" line="535"/>
         <source>Custom Note Names</source>
         <translation>Nombres personalizados de notas</translation>
     </message>
     <message>
-        <location filename="vpiano.cpp" line="537"/>
+        <location filename="vpiano.cpp" line="535"/>
         <source>Names:</source>
         <translation>Nombres:</translation>
     </message>
@@ -441,12 +472,12 @@ Copyright (C) 2006-2022 Pedro Lopez-Cabanillas
 Este programa se ofrece SIN GARANTÍA ALGUNA. Este programa es software libre, y usted puede redistribuirlo bajo ciertas condiciones; vea el archivo LICENSE para detalles.</translation>
     </message>
     <message>
-        <location filename="vpianomain.cpp" line="124"/>
+        <location filename="vpianomain.cpp" line="131"/>
         <source>Portable settings mode</source>
         <translation>Modo de ajustes portables</translation>
     </message>
     <message>
-        <location filename="vpianomain.cpp" line="138"/>
+        <location filename="vpianomain.cpp" line="145"/>
         <source>Fatal error from a MIDI backend.</source>
         <translation>Error grave en el soporte MIDI.</translation>
     </message>
