@@ -45,29 +45,6 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags)
 {
     ui.setupUi(this);
 
-    bool mouseInputEnabled = true;
-    bool touchInputEnabled = false;
-#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
-    const QList<const QTouchDevice*> devs = QTouchDevice::devices();
-    for(const QTouchDevice *dev : devs) {
-        if (dev->type() == QTouchDevice::TouchScreen) {
-            mouseInputEnabled = false;
-            touchInputEnabled = true;
-            break;
-        }
-    }
-#else
-    foreach(const QInputDevice *dev, QInputDevice::devices()) {
-        if (dev->type() == QInputDevice::DeviceType::TouchScreen) {
-            mouseInputEnabled = false;
-            touchInputEnabled = true;
-            break;
-        }
-    }
-#endif
-    ui.pianokeybd->setMouseEnabled(mouseInputEnabled);
-    ui.pianokeybd->setTouchEnabled(touchInputEnabled);
-
     connect(ui.pianokeybd, &PianoKeybd::noteOn, this, QOverload<int,int>::of(&VPiano::slotNoteOn));
     connect(ui.pianokeybd, &PianoKeybd::noteOff, this, QOverload<int,int>::of(&VPiano::slotNoteOff));
     connect(ui.pianokeybd, &PianoKeybd::signalName, this, &VPiano::slotNoteName);
@@ -78,6 +55,11 @@ VPiano::VPiano( QWidget * parent, Qt::WindowFlags flags)
     connect(ui.actionPreferences, &QAction::triggered, this,  &VPiano::slotPreferences);
     connect(ui.actionNames_Font, &QAction::triggered, this, &VPiano::slotChangeFont);
     connect(ui.actionInverted_Keys_Color, &QAction::triggered, this, &VPiano::slotInvertedColors);
+    connect(ui.actionRaw_Computer_Keyboard, &QAction::triggered, this, &VPiano::slotRawKeyboard);
+    connect(ui.actionComputer_Keyboard_Input, &QAction::triggered, this, &VPiano::slotKeyboardInput);
+    connect(ui.actionMouse_Input, &QAction::triggered, this, &VPiano::slotMouseInput);
+    connect(ui.actionTouch_Screen_Input, &QAction::triggered, this, &VPiano::slotTouchScreenInput);
+    connect(ui.actionOctave_Subscript_Designation, &QAction::triggered, this, &VPiano::slotOctaveSubscript);
 
     QActionGroup* nameGroup = new QActionGroup(this);
     nameGroup->setExclusive(true);
@@ -143,7 +125,7 @@ void VPiano::initialize()
 
     m_midiOut = man.findOutput(VPianoSettings::instance()->lastOutputBackend());
     if (m_midiOut == nullptr) {
-        qFatal("Unable to find a suitable output backend");
+        qFatal("Unable to find a suitable output backend. You may need to set the DRUMSTICKRT environment variable.");
     }
 
     drumstick::widgets::SettingsFactory settings;
@@ -409,6 +391,10 @@ void VPiano::readSettings()
         break;
     }
 
+    bool octaveSubscript = VPianoSettings::instance()->octaveSubscript();
+    ui.pianokeybd->setOctaveSubscript(octaveSubscript);
+    ui.actionOctave_Subscript_Designation->setChecked(octaveSubscript);
+
     ui.statusBar->show();
 
     ui.pianokeybd->setBaseOctave(VPianoSettings::instance()->baseOctave());
@@ -425,6 +411,18 @@ void VPiano::readSettings()
 
     ui.actionInverted_Keys_Color->setChecked(VPianoSettings::instance()->invertedKeys());
     slotInvertedColors(ui.actionInverted_Keys_Color->isChecked());
+
+    ui.actionRaw_Computer_Keyboard->setChecked(VPianoSettings::instance()->rawKeyboard());
+    slotRawKeyboard(ui.actionRaw_Computer_Keyboard->isChecked());
+
+    ui.actionComputer_Keyboard_Input->setChecked(VPianoSettings::instance()->keyboardInput());
+    slotKeyboardInput(ui.actionComputer_Keyboard_Input->isChecked());
+
+    ui.actionMouse_Input->setChecked(VPianoSettings::instance()->mouseInput());
+    slotMouseInput(ui.actionMouse_Input->isChecked());
+
+    ui.actionTouch_Screen_Input->setChecked(VPianoSettings::instance()->touchScreenInput());
+    slotTouchScreenInput(ui.actionTouch_Screen_Input->isChecked());
 }
 
 void VPiano::setPortableConfig(const QString fileName)
@@ -585,3 +583,42 @@ void VPiano::slotInvertedColors(bool checked)
     ui.pianokeybd->setForegroundPalette(fpal);
     VPianoSettings::instance()->setInvertedKeys(checked);
 }
+
+void VPiano::slotRawKeyboard(bool checked)
+{
+    //qDebug() << Q_FUNC_INFO << checked;
+    if (checked) {
+        ui.pianokeybd->resetRawKeyboardMap();
+    } else {
+        ui.pianokeybd->resetKeyboardMap();
+    }
+    ui.pianokeybd->setRawKeyboardMode(checked);
+    VPianoSettings::instance()->setRawKeyboard(checked);
+}
+
+void VPiano::slotKeyboardInput(bool checked)
+{
+    //qDebug() << Q_FUNC_INFO << checked;
+    ui.pianokeybd->setKeyboardEnabled(checked);
+    VPianoSettings::instance()->setKeyboardInput(checked);
+}
+
+void VPiano::slotMouseInput(bool checked)
+{
+    //qDebug() << Q_FUNC_INFO << checked;
+    ui.pianokeybd->setMouseEnabled(checked);
+    VPianoSettings::instance()->setMouseInput(checked);
+}
+
+void VPiano::slotTouchScreenInput(bool checked)
+{
+    //qDebug() << Q_FUNC_INFO << checked;
+    ui.pianokeybd->setTouchEnabled(checked);
+    VPianoSettings::instance()->setTouchScreenInput(checked);
+}
+
+void VPiano::slotOctaveSubscript(bool checked)
+{
+    ui.pianokeybd->setOctaveSubscript(checked);
+    VPianoSettings::instance()->setOctaveSubscript(checked);
+}
