@@ -57,6 +57,11 @@ public slots:
     void slotCustomNames(bool sharps);
     void slotNoteName(const QString& name);
     void slotInvertedColors(bool checked);
+    void slotRawKeyboard(bool checked);
+    void slotKeyboardInput(bool checked);
+    void slotMouseInput(bool checked);
+    void slotTouchScreenInput(bool checked);
+    void slotOctaveSubscript(bool checked);
 
 private:
     void initialize();
